@@ -1,4 +1,3 @@
-
 #' @export
 ci.ivFixed <- ci.default
 
@@ -34,10 +33,13 @@ p_value.ivFixed <- function(model, method = "wald", ...) {
 }
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.ivFixed <- function(model,
-                                     ci = .95,
+                                     ci = 0.95,
                                      ci_method = "wald",
+                                     keep = NULL,
+                                     drop = NULL,
                                      verbose = TRUE,
                                      ...) {
   out <- .model_parameters_generic(
@@ -45,9 +47,11 @@ model_parameters.ivFixed <- function(model,
     ci = ci,
     ci_method = ci_method,
     merge_by = "Parameter",
+    keep_parameters = keep,
+    drop_parameters = drop,
     verbose = verbose,
     ...
   )
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
