@@ -4,80 +4,7 @@
 # model parameters ---------------------------
 
 
-#' Parameters from CFA/SEM models
-#'
-#' Format CFA/SEM objects from the lavaan package (Rosseel, 2012; Merkle and Rosseel 2018).
-#'
-#' @param model CFA or SEM created by the `lavaan::cfa` or `lavaan::sem`
-#'   functions.
-#' @param standardize Return standardized parameters (standardized coefficients).
-#'   Can be `TRUE` (or `"all"` or `"std.all"`) for standardized
-#'   estimates based on both the variances of observed and latent variables;
-#'   `"latent"` (or `"std.lv"`) for standardized estimates based
-#'   on the variances of the latent variables only; or `"no_exogenous"`
-#'   (or `"std.nox"`) for standardized estimates based on both the
-#'   variances of observed and latent variables, but not the variances of
-#'   exogenous covariates. See `lavaan::standardizedsolution` for details.
-#' @inheritParams model_parameters.default
-#' @param component What type of links to return. Can be `"all"` or some of `c("regression", "correlation", "loading", "variance", "mean")`.
-#' @param ... Arguments passed to or from other methods.
-#'
-#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/parameters.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
-#'
-#' @examples
-#' library(parameters)
-#'
-#' # lavaan -------------------------------------
-#' if (require("lavaan", quietly = TRUE)) {
-#'
-#'   # Confirmatory Factor Analysis (CFA) ---------
-#'
-#'   structure <- " visual  =~ x1 + x2 + x3
-#'                  textual =~ x4 + x5 + x6
-#'                  speed   =~ x7 + x8 + x9 "
-#'   model <- lavaan::cfa(structure, data = HolzingerSwineford1939)
-#'   model_parameters(model)
-#'   model_parameters(model, standardize = TRUE)
-#'
-#'   # filter parameters
-#'   model_parameters(
-#'     model,
-#'     parameters = list(
-#'       To = "^(?!visual)",
-#'       From = "^(?!(x7|x8))"
-#'     )
-#'   )
-#'
-#'   # Structural Equation Model (SEM) ------------
-#'
-#'   structure <- "
-#'     # latent variable definitions
-#'       ind60 =~ x1 + x2 + x3
-#'       dem60 =~ y1 + a*y2 + b*y3 + c*y4
-#'       dem65 =~ y5 + a*y6 + b*y7 + c*y8
-#'     # regressions
-#'       dem60 ~ ind60
-#'       dem65 ~ ind60 + dem60
-#'     # residual correlations
-#'       y1 ~~ y5
-#'       y2 ~~ y4 + y6
-#'       y3 ~~ y7
-#'       y4 ~~ y8
-#'       y6 ~~ y8
-#'   "
-#'   model <- lavaan::sem(structure, data = PoliticalDemocracy)
-#'   model_parameters(model)
-#'   model_parameters(model, standardize = TRUE)
-#' }
-#' @return A data frame of indices related to the model's parameters.
-#'
-#' @references
-#' - Rosseel Y (2012). lavaan: An R Package for Structural Equation
-#'   Modeling. Journal of Statistical Software, 48(2), 1-36.
-#'
-#' - Merkle EC , Rosseel Y (2018). blavaan: Bayesian Structural Equation
-#'   Models via Parameter Expansion. Journal of Statistical Software, 85(4),
-#'   1-30. http://www.jstatsoft.org/v85/i04/
+#' @rdname model_parameters.principal
 #' @export
 model_parameters.lavaan <- function(model,
                                     ci = 0.95,
@@ -85,7 +12,6 @@ model_parameters.lavaan <- function(model,
                                     component = c("regression", "correlation", "loading", "defined"),
                                     keep = NULL,
                                     drop = NULL,
-                                    parameters = keep,
                                     verbose = TRUE,
                                     ...) {
   params <- .extract_parameters_lavaan(model,
@@ -116,9 +42,9 @@ model_parameters.lavaan <- function(model,
 model_parameters.blavaan <- function(model,
                                      centrality = "median",
                                      dispersion = FALSE,
-                                     ci = .95,
-                                     ci_method = "hdi",
-                                     test = c("pd", "rope"),
+                                     ci = 0.95,
+                                     ci_method = "eti",
+                                     test = "pd",
                                      rope_range = "default",
                                      rope_ci = 0.95,
                                      diagnostic = c("ESS", "Rhat"),
@@ -126,11 +52,8 @@ model_parameters.blavaan <- function(model,
                                      standardize = NULL,
                                      keep = NULL,
                                      drop = NULL,
-                                     parameters = keep,
                                      verbose = TRUE,
                                      ...) {
-
-
   # Processing
   params <- .extract_parameters_bayesian(
     model,
@@ -165,7 +88,7 @@ model_parameters.blavaan <- function(model,
     ...
   )
 
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(params) <- c("parameters_sem", "see_parameters_sem", class(params))
 
   params
@@ -178,7 +101,7 @@ model_parameters.blavaan <- function(model,
 
 
 #' @export
-ci.lavaan <- function(x, ci = .95, ...) {
+ci.lavaan <- function(x, ci = 0.95, ...) {
   out <- .extract_parameters_lavaan(model = x, ci = ci, ...)
   out$CI <- ci
   out[out$Operator != "~1", c("To", "Operator", "From", "CI", "CI_low", "CI_high")]
@@ -237,7 +160,16 @@ print.parameters_sem <- function(x, digits = 2, ci_digits = 2, p_digits = 3, ...
 
   verbose <- .additional_arguments(x, "verbose", TRUE)
 
-  formatted_table <- format(x = x, digits = digits, ci_digits, p_digits = p_digits, format = "text", ci_brackets = TRUE, ci_width = "auto", ...)
+  formatted_table <- format(
+    x = x,
+    digits = digits,
+    ci_digits,
+    p_digits = p_digits,
+    format = "text",
+    ci_brackets = TRUE,
+    ci_width = "auto",
+    ...
+  )
   cat(insight::export_table(formatted_table, format = "text", ...))
 
   if (isTRUE(verbose)) {
@@ -249,6 +181,7 @@ print.parameters_sem <- function(x, digits = 2, ci_digits = 2, p_digits = 3, ...
 
 
 #' @export
+#' @inheritParams stats::predict
 predict.parameters_sem <- function(object, newdata = NULL, ...) {
   insight::check_if_installed("lavaan")
 
