@@ -4,21 +4,26 @@
 ###### .metaplus -------------------
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.metaplus <- function(model,
-                                      ci = .95,
+                                      ci = 0.95,
                                       bootstrap = FALSE,
                                       iterations = 1000,
                                       standardize = NULL,
                                       exponentiate = FALSE,
                                       include_studies = TRUE,
+                                      keep = NULL,
+                                      drop = NULL,
                                       verbose = TRUE,
                                       ...) {
   if (!missing(ci)) {
     if (isTRUE(verbose)) {
-      message(insight::format_message("'metaplus' models do not support other levels for confidence intervals than 0.95. Argument 'ci' is ignored."))
+      insight::format_alert(
+        "'metaplus' models do not support other levels for confidence intervals than 0.95. Argument 'ci' is ignored."
+      )
     }
-    ci <- .95
+    ci <- 0.95
   }
 
   meta_analysis_overall <- suppressWarnings(.model_parameters_generic(
@@ -29,6 +34,8 @@ model_parameters.metaplus <- function(model,
     merge_by = "Parameter",
     standardize = standardize,
     exponentiate = exponentiate,
+    keep_parameters = keep,
+    drop_parameters = drop,
     ...
   ))
 
@@ -39,7 +46,7 @@ model_parameters.metaplus <- function(model,
   } else if (!is.null(model$k)) {
     sprintf("Study %i", 1:model[["k"]])
   } else {
-    sprintf("Study %i", 1:length(model$yi))
+    sprintf("Study %i", seq_along(model$yi))
   }
 
   alpha <- (1 + ci) / 2
@@ -77,13 +84,13 @@ model_parameters.metaplus <- function(model,
   }
 
   original_attributes$names <- names(out)
-  original_attributes$row.names <- 1:nrow(out)
+  original_attributes$row.names <- seq_len(nrow(out))
   original_attributes$pretty_names <- stats::setNames(out$Parameter, out$Parameter)
   attributes(out) <- original_attributes
 
   # no df
   out$df_error <- NULL
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   attr(out, "measure") <- "Estimate"
 
   if (!"Method" %in% names(out)) {
@@ -104,10 +111,10 @@ standard_error.metaplus <- function(model, ...) {
 
   out <- .data_frame(
     Parameter = .remove_backticks_from_string(rownames(model$results)),
-    SE = cis / (2 * stats::qnorm(.975))
+    SE = cis / (2 * stats::qnorm(0.975))
   )
 
-  out$Parameter[grepl("muhat", out$Parameter)] <- "(Intercept)"
+  out$Parameter[grepl("muhat", out$Parameter, fixed = TRUE)] <- "(Intercept)"
   out
 }
 
@@ -118,7 +125,7 @@ p_value.metaplus <- function(model, ...) {
     Parameter = .remove_backticks_from_string(rownames(model$results)),
     p = as.vector(model$results[, "pvalue"])
   )
-  out$Parameter[grepl("muhat", out$Parameter)] <- "(Intercept)"
+  out$Parameter[grepl("muhat", out$Parameter, fixed = TRUE)] <- "(Intercept)"
   out
 }
 
@@ -131,7 +138,7 @@ ci.metaplus <- function(x, ...) {
     CI_high = as.vector(x$results[, "95% ci.ub"])
   )
 
-  out$Parameter[grepl("muhat", out$Parameter)] <- "(Intercept)"
+  out$Parameter[grepl("muhat", out$Parameter, fixed = TRUE)] <- "(Intercept)"
   out
 }
 
@@ -141,18 +148,18 @@ ci.metaplus <- function(x, ...) {
 ###### .meta_random -------------------
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.meta_random <- function(model,
-                                         ci = .95,
-                                         ci_method = "hdi",
+                                         ci = 0.95,
+                                         ci_method = "eti",
                                          exponentiate = FALSE,
                                          include_studies = TRUE,
                                          verbose = TRUE,
                                          ...) {
-
   # process arguments
   params <- as.data.frame(model$estimates)
-  ci_method <- match.arg(ci_method, choices = c("hdi", "eti"))
+  ci_method <- match.arg(ci_method, choices = c("hdi", "eti", "quantile"))
 
   # parameters of studies included
   study_params <- model$data
@@ -215,9 +222,9 @@ model_parameters.meta_random <- function(model,
     out <- out[out$Parameter %in% c("Overall", "tau"), ]
   }
 
-  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
-    out <- .exponentiate_parameters(out, model, exponentiate)
-  }
+  # exponentiate coefficients and SE/CI, if requested
+  out <- .exponentiate_parameters(out, model, exponentiate)
+
   out <- .add_model_parameters_attributes(
     params = out,
     model = model,
@@ -230,7 +237,7 @@ model_parameters.meta_random <- function(model,
 
   # final atributes
   attr(out, "measure") <- "Estimate"
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(out) <- c("parameters_model", "see_parameters_model", class(params))
 
   if (!"Method" %in% names(out)) {
@@ -251,16 +258,16 @@ standard_error.meta_random <- function(model, ...) {
     SE = params$sd,
     stringsAsFactors = FALSE
   )
-  out$Parameter[grepl("d", out$Parameter)] <- "(Intercept)"
+  out$Parameter[grepl("d", out$Parameter, fixed = TRUE)] <- "(Intercept)"
   out
 }
 
 
 #' @export
-ci.meta_random <- function(x, method = "hdi", ...) {
+ci.meta_random <- function(x, method = "eti", ...) {
   # process arguments
   params <- as.data.frame(x$estimates)
-  ci_method <- match.arg(method, choices = c("hdi", "eti"))
+  ci_method <- match.arg(method, choices = c("hdi", "eti", "quantile"))
 
   # extract ci-level and find ci-columns
   ci <- .meta_bma_extract_ci(params)
@@ -268,13 +275,13 @@ ci.meta_random <- function(x, method = "hdi", ...) {
 
   out <- data.frame(
     Parameter = rownames(params),
-    CI = .95,
+    ci = 0.95,
     CI_low = params[[ci_cols[1]]],
     CI_high = params[[ci_cols[2]]],
     stringsAsFactors = FALSE
   )
 
-  out$Parameter[grepl("d", out$Parameter)] <- "(Intercept)"
+  out$Parameter[grepl("d", out$Parameter, fixed = TRUE)] <- "(Intercept)"
   out
 }
 
@@ -283,7 +290,7 @@ ci.meta_random <- function(x, method = "hdi", ...) {
 
 ###### .meta_fixed -------------------
 
-
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.meta_fixed <- model_parameters.meta_random
 
@@ -301,18 +308,18 @@ ci.meta_fixed <- ci.meta_random
 ###### .meta_bma -------------------
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.meta_bma <- function(model,
-                                      ci = .95,
-                                      ci_method = "hdi",
+                                      ci = 0.95,
+                                      ci_method = "eti",
                                       exponentiate = FALSE,
                                       include_studies = TRUE,
                                       verbose = TRUE,
                                       ...) {
-
   # process arguments
   params <- as.data.frame(model$estimates)
-  ci_method <- match.arg(ci_method, choices = c("hdi", "eti"))
+  ci_method <- match.arg(ci_method, choices = c("hdi", "eti", "quantile"))
 
   # parameters of studies included
   study_params <- model$meta$fixed$data
@@ -361,9 +368,9 @@ model_parameters.meta_bma <- function(model,
     out <- out[out$Parameter %in% c("averaged", "fixed", "random"), ]
   }
 
-  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
-    out <- .exponentiate_parameters(out, model, exponentiate)
-  }
+  # exponentiate coefficients and SE/CI, if requested
+  out <- .exponentiate_parameters(out, model, exponentiate)
+
   out <- .add_model_parameters_attributes(
     params = out,
     model = model,
@@ -376,7 +383,7 @@ model_parameters.meta_bma <- function(model,
 
   # final attributes
   attr(out, "measure") <- "Estimate"
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(out) <- c("parameters_model", "see_parameters_model", class(params))
 
   if (!"Method" %in% names(out)) {
