@@ -2,18 +2,22 @@
 
 #' @export
 model_parameters.svyglm <- function(model,
-                                    ci = .95,
+                                    ci = 0.95,
                                     ci_method = "wald",
                                     bootstrap = FALSE,
                                     iterations = 1000,
                                     standardize = NULL,
                                     exponentiate = FALSE,
-                                    robust = FALSE,
                                     p_adjust = NULL,
+                                    summary = getOption("parameters_summary", FALSE),
+                                    keep = NULL,
+                                    drop = NULL,
                                     verbose = TRUE,
                                     ...) {
   if (insight::n_obs(model) > 1e4 && ci_method == "likelihood") {
-    message(insight::format_message("Likelihood confidence intervals may take longer time to compute. Use 'df_method=\"wald\"' for faster computation of CIs."))
+    insight::format_alert(
+      "Likelihood confidence intervals may take longer time to compute. Use 'ci_method=\"wald\"' for faster computation of CIs."
+    )
   }
 
   out <- .model_parameters_generic(
@@ -25,12 +29,14 @@ model_parameters.svyglm <- function(model,
     merge_by = "Parameter",
     standardize = standardize,
     exponentiate = exponentiate,
-    robust = robust,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    summary = summary,
     ...
   )
 
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
@@ -84,7 +90,7 @@ standard_error.svyolr <- standard_error.svyglm
 # confidence intervals -----------------------------------
 
 #' @export
-ci.svyglm <- function(x, ci = .95, method = "wald", ...) {
+ci.svyglm <- function(x, ci = 0.95, method = "wald", ...) {
   method <- match.arg(method, choices = c("wald", "residual", "normal", "likelihood"))
   if (method == "likelihood") {
     out <- lapply(ci, function(i) .ci_likelihood(model = x, ci = i))
